@@ -21,7 +21,7 @@
 #include "qgis_sip.h"
 #include "qgsattributeform.h"
 #include "qgstrackedvectorlayertools.h"
-#include "qgsactionmenu.h"
+#include "qgsmaplayeractioncontextgenerator.h"
 
 #include <QDialog>
 #include <QMenuBar>
@@ -29,12 +29,13 @@
 #include "qgis_gui.h"
 
 class QgsHighlight;
+class QgsActionMenu;
 
 /**
  * \ingroup gui
  * \class QgsAttributeDialog
  */
-class GUI_EXPORT QgsAttributeDialog : public QDialog
+class GUI_EXPORT QgsAttributeDialog : public QDialog, public QgsMapLayerActionContextGenerator
 {
     Q_OBJECT
 
@@ -95,6 +96,8 @@ class GUI_EXPORT QgsAttributeDialog : public QDialog
      */
     bool event( QEvent *e ) override;
 
+    void showEvent( QShowEvent *event ) override;
+
     /**
      * Sets \a extraScope as an additional expression context scope to be used
      * for calculations in this form.
@@ -103,6 +106,8 @@ class GUI_EXPORT QgsAttributeDialog : public QDialog
      */
     void setExtraContextScope( QgsExpressionContextScope *extraScope SIP_TRANSFER );
 
+    QgsMapLayerActionContext createActionContext() override;
+
   public slots:
     void accept() override;
     void reject() override;
@@ -116,8 +121,6 @@ class GUI_EXPORT QgsAttributeDialog : public QDialog
     QString mSettingsPath;
     // Used to sync multiple widgets for the same field
     QgsHighlight *mHighlight = nullptr;
-    int mFormNr;
-    bool mShowDialogButtons;
     QString mReturnvarname;
     QgsAttributeForm *mAttributeForm = nullptr;
     QgsFeature *mOwnedFeature = nullptr;
@@ -125,13 +128,12 @@ class GUI_EXPORT QgsAttributeDialog : public QDialog
 
     QgsTrackedVectorLayerTools mTrackedVectorLayerTools;
 
-    // true if this dialog is editable
-    bool mEditable;
-
     QgsActionMenu *mMenu;
+    QMenuBar *mMenuBar = nullptr;
 
     static int sFormCounter;
 
+    bool mFirstShow = true;
     void saveGeometry();
     void restoreGeometry();
 };
