@@ -90,7 +90,7 @@ class GUI_EXPORT QgsDatumTransformDialog : public QDialog, private Ui::QgsDatumT
                              bool forceChoice = true,
                              QPair<int, int> selectedDatumTransforms = qMakePair( -1, -1 ),
                              QWidget *parent = nullptr,
-                             Qt::WindowFlags f = nullptr,
+                             Qt::WindowFlags f = Qt::WindowFlags(),
                              const QString &selectedProj = QString(),
                              QgsMapCanvas *mapCanvas = nullptr,
                              bool allowFallback = true );
@@ -100,7 +100,6 @@ class GUI_EXPORT QgsDatumTransformDialog : public QDialog, private Ui::QgsDatumT
 
     /**
      * Returns the source and destination transforms, each being a pair of QgsCoordinateReferenceSystems and datum transform code
-     * \since 3.0
      */
     TransformInfo selectedDatumTransform();
 
@@ -125,7 +124,7 @@ class GUI_EXPORT QgsDatumTransformDialog : public QDialog, private Ui::QgsDatumT
     void setOKButtonEnabled();
 
     /**
-     * Returns true if the dialog should be shown and the user prompted to make the transformation selection.
+     * Returns TRUE if the dialog should be shown and the user prompted to make the transformation selection.
      *
      * \see defaultDatumTransform()
      */
