@@ -1,11 +1,10 @@
-# -*- coding: utf-8 -*-
 ###############################################################################
 #
 # Copyright (C) 2010 NextGIS (http://nextgis.org),
 #                    Alexander Bruy (alexander.bruy@gmail.com),
 #                    Maxim Dubinin (sim@gis-lab.info)
 #
-# Copyright (C) 2014 Tom Kralidis (tomkralidis@gmail.com)
+# Copyright (C) 2024 Tom Kralidis (tomkralidis@gmail.com)
 # Copyright (C) 2014 Angelos Tzotsos (tzotsos@gmail.com)
 #
 # This source is free software; you can redistribute it and/or modify it under
@@ -26,28 +25,25 @@
 
 from gettext import gettext, ngettext
 import logging
+import warnings
 import os
-import codecs
 import webbrowser
 from xml.dom.minidom import parseString
 import xml.etree.ElementTree as etree
 
-from jinja2 import Environment, FileSystemLoader
-from pygments import highlight
-from pygments.lexers import XmlLexer
-from pygments.formatters import HtmlFormatter
+with warnings.catch_warnings():
+    warnings.filterwarnings("ignore", category=DeprecationWarning)
+    from jinja2 import Environment, FileSystemLoader
+
+from qgis.core import Qgis, QgsMessageLog, QgsSettings
 from qgis.PyQt.QtCore import QUrl, QUrlQuery
 from qgis.PyQt.QtWidgets import QMessageBox
 from qgis.PyQt.uic import loadUiType
 
-from qgis.core import Qgis, QgsSettings
+LOGGER = QgsMessageLog()
 
 
-LOGGER = logging.getLogger('MetaSearch')
-
-
-class StaticContext(object):
-
+class StaticContext:
     """base configuration / scaffolding"""
 
     def __init__(self):
@@ -57,13 +53,12 @@ class StaticContext(object):
 
 def get_ui_class(ui_file):
     """return class object of a uifile"""
-    ui_file_full = '%s%sui%s%s' % (os.path.dirname(os.path.abspath(__file__)),
-                                   os.sep, os.sep, ui_file)
+    ui_file_full = '{}{}ui{}{}'.format(os.path.dirname(os.path.abspath(__file__)), os.sep, os.sep, ui_file)
     return loadUiType(ui_file_full)[0]
 
 
 def render_template(language, context, data, template):
-    """Renders HTML display of metadata XML"""
+    """Renders HTML display of raw API request/response/content"""
 
     env = Environment(extensions=['jinja2.ext.i18n'],
                       loader=FileSystemLoader(context.ppath))
@@ -82,11 +77,11 @@ def get_connections_from_file(parent, filename):
         doc = etree.parse(filename).getroot()
         if doc.tag != 'qgsCSWConnections':
             error = 1
-            msg = parent.tr('Invalid CSW connections XML.')
+            msg = parent.tr('Invalid Catalog connections XML.')
     except etree.ParseError as err:
         error = 1
         msg = parent.tr('Cannot parse XML file: {0}').format(err)
-    except IOError as err:
+    except OSError as err:
         error = 1
         msg = parent.tr('Cannot open file: {0}').format(err)
 
@@ -112,20 +107,6 @@ def prettify_xml(xml):
         return parseString(xml).toprettyxml()
 
 
-def highlight_xml(context, xml):
-    """render XML as highlighted HTML"""
-
-    hformat = HtmlFormatter()
-    css = hformat.get_style_defs('.highlight')
-    body = highlight(prettify_xml(xml), XmlLexer(), hformat)
-
-    env = Environment(loader=FileSystemLoader(context.ppath))
-
-    template_file = 'resources/templates/xml_highlight.html'
-    template = env.get_template(template_file)
-    return template.render(css=css, body=body)
-
-
 def get_help_url():
     """return QGIS MetaSearch help documentation link"""
 
@@ -137,8 +118,7 @@ def get_help_url():
     else:
         version = '.'.join([major, minor])
 
-    path = '%s/%s/docs/user_manual/plugins/core_plugins/plugins_metasearch.html' % \
-           (version, locale_name)
+    path = f'{version}/{locale_name}/docs/user_manual/plugins/core_plugins/plugins_metasearch.html'  # noqa
 
     return '/'.join(['https://docs.qgis.org', path])
 
@@ -164,7 +144,7 @@ def serialize_string(input_string):
     all_other_tokens_as_string = input_string.replace(last_token, '')
 
     if last_token.isdigit():
-        value = '%s%s' % (all_other_tokens_as_string, int(last_token) + 1)
+        value = f'{all_other_tokens_as_string}{int(last_token) + 1}'
     else:
         value = '%s 1' % input_string
 
@@ -186,3 +166,9 @@ def clean_ows_url(url):
         url.setQuery(query_string)
 
     return url.toString()
+
+
+def log_message(message, level=Qgis.MessageLevel.Info):
+    """helper function to emit logging messages"""
+
+    LOGGER.logMessage(message, 'MetaSearch', level)
