@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 ***************************************************************************
     retile.py
@@ -21,11 +19,8 @@ __author__ = 'Médéric Ribreux'
 __date__ = 'January 2016'
 __copyright__ = '(C) 2016, Médéric Ribreux'
 
-# This will get replaced with a git SHA1 when you do a git archive
-
-__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
-
 from qgis.core import (QgsProcessing,
+                       QgsProcessingException,
                        QgsProcessingParameterDefinition,
                        QgsProcessingParameterMultipleLayers,
                        QgsProcessingParameterCrs,
@@ -41,7 +36,6 @@ from processing.tools.system import isWindows
 
 
 class retile(GdalAlgorithm):
-
     INPUT = 'INPUT'
     TILE_SIZE_X = 'TILE_SIZE_X'
     TILE_SIZE_Y = 'TILE_SIZE_Y'
@@ -52,6 +46,7 @@ class retile(GdalAlgorithm):
     FORMAT = 'FORMAT'
     RESAMPLING = 'RESAMPLING'
     OPTIONS = 'OPTIONS'
+    EXTRA = 'EXTRA'
     DATA_TYPE = 'DATA_TYPE'
     DELIMITER = 'DELIMITER'
     ONLY_PYRAMIDS = 'ONLY_PYRAMIDS'
@@ -59,65 +54,70 @@ class retile(GdalAlgorithm):
     OUTPUT = 'OUTPUT'
     OUTPUT_CSV = 'OUTPUT_CSV'
 
-    TYPES = ['Byte', 'Int16', 'UInt16', 'UInt32', 'Int32', 'Float32', 'Float64', 'CInt16', 'CInt32', 'CFloat32', 'CFloat64']
+    TYPES = ['Byte', 'Int16', 'UInt16', 'UInt32', 'Int32', 'Float32', 'Float64', 'CInt16', 'CInt32', 'CFloat32', 'CFloat64', 'Int8']
 
     def __init__(self):
         super().__init__()
 
     def initAlgorithm(self, config=None):
-        self.methods = ((self.tr('Nearest neighbour'), 'near'),
-                        (self.tr('Bilinear'), 'bilinear'),
-                        (self.tr('Cubic'), 'cubic'),
-                        (self.tr('Cubic spline'), 'cubicspline'),
-                        (self.tr('Lanczos windowed sinc'), 'lanczos'),)
+        self.methods = ((self.tr('Nearest Neighbour'), 'near'),
+                        (self.tr('Bilinear (2x2 Kernel)'), 'bilinear'),
+                        (self.tr('Cubic (4x4 Kernel)'), 'cubic'),
+                        (self.tr('Cubic B-Spline (4x4 Kernel)'), 'cubicspline'),
+                        (self.tr('Lanczos (6x6 Kernel)'), 'lanczos'),)
 
         self.addParameter(QgsProcessingParameterMultipleLayers(self.INPUT,
                                                                self.tr('Input files'),
-                                                               QgsProcessing.TypeRaster))
+                                                               QgsProcessing.SourceType.TypeRaster))
         self.addParameter(QgsProcessingParameterNumber(self.TILE_SIZE_X,
                                                        self.tr('Tile width'),
-                                                       type=QgsProcessingParameterNumber.Integer,
+                                                       type=QgsProcessingParameterNumber.Type.Integer,
                                                        minValue=0,
                                                        defaultValue=256))
         self.addParameter(QgsProcessingParameterNumber(self.TILE_SIZE_Y,
                                                        self.tr('Tile height'),
-                                                       type=QgsProcessingParameterNumber.Integer,
+                                                       type=QgsProcessingParameterNumber.Type.Integer,
                                                        minValue=0,
                                                        defaultValue=256))
         self.addParameter(QgsProcessingParameterNumber(self.OVERLAP,
                                                        self.tr('Overlap in pixels between consecutive tiles'),
-                                                       type=QgsProcessingParameterNumber.Integer,
+                                                       type=QgsProcessingParameterNumber.Type.Integer,
                                                        minValue=0,
                                                        defaultValue=0))
         self.addParameter(QgsProcessingParameterNumber(self.LEVELS,
                                                        self.tr('Number of pyramids levels to build'),
-                                                       type=QgsProcessingParameterNumber.Integer,
+                                                       type=QgsProcessingParameterNumber.Type.Integer,
                                                        minValue=0,
                                                        defaultValue=1))
 
-        params = []
-        params.append(QgsProcessingParameterCrs(self.SOURCE_CRS,
-                                                self.tr('Source coordinate reference system'),
-                                                optional=True))
-        params.append(QgsProcessingParameterEnum(self.RESAMPLING,
-                                                 self.tr('Resampling method'),
-                                                 options=[i[0] for i in self.methods],
-                                                 allowMultiple=False,
-                                                 defaultValue=0))
-        params.append(QgsProcessingParameterString(self.DELIMITER,
-                                                   self.tr('Column delimiter used in the CSV file'),
-                                                   defaultValue=';',
-                                                   optional=True))
+        params = [
+            QgsProcessingParameterCrs(self.SOURCE_CRS,
+                                      self.tr('Source coordinate reference system'),
+                                      optional=True,
+                                      ),
+            QgsProcessingParameterEnum(self.RESAMPLING,
+                                       self.tr('Resampling method'),
+                                       options=[i[0] for i in self.methods],
+                                       allowMultiple=False,
+                                       defaultValue=0),
+            QgsProcessingParameterString(self.DELIMITER,
+                                         self.tr('Column delimiter used in the CSV file'),
+                                         defaultValue=';',
+                                         optional=True)
 
+        ]
         options_param = QgsProcessingParameterString(self.OPTIONS,
                                                      self.tr('Additional creation options'),
                                                      defaultValue='',
                                                      optional=True)
-        options_param.setMetadata({
-            'widget_wrapper': {
-                'class': 'processing.algs.gdal.ui.RasterOptionsWidget.RasterOptionsWidgetWrapper'}})
+        options_param.setMetadata({'widget_wrapper': {'widget_type': 'rasteroptions'}})
         params.append(options_param)
 
+        params.append(QgsProcessingParameterString(self.EXTRA,
+                                                   self.tr('Additional command-line parameters'),
+                                                   defaultValue=None,
+                                                   optional=True))
+
         params.append(QgsProcessingParameterEnum(self.DATA_TYPE,
                                                  self.tr('Output data type'),
                                                  self.TYPES,
@@ -132,7 +132,7 @@ class retile(GdalAlgorithm):
                                                     defaultValue=False))
 
         for param in params:
-            param.setFlags(param.flags() | QgsProcessingParameterDefinition.FlagAdvanced)
+            param.setFlags(param.flags() | QgsProcessingParameterDefinition.Flag.FlagAdvanced)
             self.addParameter(param)
 
         self.addParameter(QgsProcessingParameterFolderDestination(self.OUTPUT,
@@ -161,17 +161,17 @@ class retile(GdalAlgorithm):
         return "gdal_retile"
 
     def getConsoleCommands(self, parameters, context, feedback, executing=True):
-        arguments = []
+        arguments = [
+            '-ps',
+            str(self.parameterAsInt(parameters, self.TILE_SIZE_X, context)),
+            str(self.parameterAsInt(parameters, self.TILE_SIZE_Y, context)),
 
-        arguments.append('-ps')
-        arguments.append(str(self.parameterAsInt(parameters, self.TILE_SIZE_X, context)))
-        arguments.append(str(self.parameterAsInt(parameters, self.TILE_SIZE_Y, context)))
+            '-overlap',
+            str(self.parameterAsInt(parameters, self.OVERLAP, context)),
 
-        arguments.append('-overlap')
-        arguments.append(str(self.parameterAsInt(parameters, self.OVERLAP, context)))
-
-        arguments.append('-levels')
-        arguments.append(str(self.parameterAsInt(parameters, self.LEVELS, context)))
+            '-levels',
+            str(self.parameterAsInt(parameters, self.LEVELS, context))
+        ]
 
         crs = self.parameterAsCrs(parameters, self.SOURCE_CRS, context)
         if crs.isValid():
@@ -181,19 +181,26 @@ class retile(GdalAlgorithm):
         arguments.append('-r')
         arguments.append(self.methods[self.parameterAsEnum(parameters, self.RESAMPLING, context)][1])
 
-        arguments.append('-ot')
-        arguments.append(self.TYPES[self.parameterAsEnum(parameters, self.DATA_TYPE, context)])
+        data_type = self.parameterAsEnum(parameters, self.DATA_TYPE, context)
+        if self.TYPES[data_type] == 'Int8' and GdalUtils.version() < 3070000:
+            raise QgsProcessingException(self.tr('Int8 data type requires GDAL version 3.7 or later'))
+
+        arguments.append('-ot ' + self.TYPES[data_type])
 
         options = self.parameterAsString(parameters, self.OPTIONS, context)
         if options:
             arguments.extend(GdalUtils.parseCreationOptions(options))
 
-        if self.parameterAsBool(parameters, self.DIR_FOR_ROW, context):
-            arguments.append('-pyramidOnly')
+        if self.EXTRA in parameters and parameters[self.EXTRA] not in (None, ''):
+            extra = self.parameterAsString(parameters, self.EXTRA, context)
+            arguments.append(extra)
 
-        if self.parameterAsBool(parameters, self.ONLY_PYRAMIDS, context):
+        if self.parameterAsBoolean(parameters, self.DIR_FOR_ROW, context):
             arguments.append('-useDirForEachRow')
 
+        if self.parameterAsBoolean(parameters, self.ONLY_PYRAMIDS, context):
+            arguments.append('-pyramidOnly')
+
         csvFile = self.parameterAsFileOutput(parameters, self.OUTPUT_CSV, context)
         if csvFile:
             arguments.append('-csv')
@@ -201,19 +208,22 @@ class retile(GdalAlgorithm):
             delimiter = self.parameterAsString(parameters, self.DELIMITER, context)
             if delimiter:
                 arguments.append('-csvDelim')
-                arguments.append('"{}"'.format(delimiter))
+                arguments.append(delimiter)
 
         arguments.append('-targetDir')
         arguments.append(self.parameterAsString(parameters, self.OUTPUT, context))
 
-        layers = [l.source() for l in self.parameterAsLayerList(parameters, self.INPUT, context)]
+        input_layers = self.parameterAsLayerList(parameters, self.INPUT, context)
+        layers = []
+        credential_options = []
+        for layer in input_layers:
+            layer_details = GdalUtils.gdal_connection_details_from_layer(layer)
+            layers.append(layer_details.connection_string)
+
+            if layer_details.credential_options:
+                credential_options.extend(
+                    layer_details.credential_options_as_arguments())
         arguments.extend(layers)
+        arguments.extend(credential_options)
 
-        if isWindows():
-            commands = ["python3", "-m", self.commandName()]
-        else:
-            commands = [self.commandName() + '.py']
-
-        commands.append(GdalUtils.escapeAndJoin(arguments))
-
-        return commands
+        return [self.commandName() + ('.bat' if isWindows() else '.py'), GdalUtils.escapeAndJoin(arguments)]
